# ImageCrawler: DummyImage 

## Purpose

Not an actual crawler.  
Dynamic Dummy Image from [https://dummyimage.com](https://dummyimage.com).


## Config

### `with` 

- the width of the image in pixels.
- type: integer

### `height` 

- the height of the image in pixels.
- type: integer
